@@ -19,11 +19,11 @@ if __name__ == "__main__":
     )
 
     parser.add_argument("-o", "--output", type=str, default="wfold_scree_plots.csv", help="Output file path")
-    parser.add_argument("-r", "--runs", type=int, default=100, help="Number of iterations per node")
-    parser.add_argument("-w", "--writefreq", type=int, default=20, help="Write frequency")
+    parser.add_argument("-r", "--runs", type=int, default=1, help="Number of iterations per node")
+    parser.add_argument("-w", "--writefreq", type=int, default=1, help="Write frequency")
     parser.add_argument("-e", "--epsilon", type=float, default=0.10, help="Epsilon")
-    parser.add_argument("-m", "--ncmin", type=float, default=2, help="Minimum number of components")
-    parser.add_argument("-M", "--ncmax", type=float, default=45, help="Maximum number of components")
+    parser.add_argument("-m", "--ncmin", type=int, default=2, help="Minimum number of components")
+    parser.add_argument("-M", "--ncmax", type=int, default=45, help="Maximum number of components")
     args = parser.parse_args()
     output = Path(args.output)
     epsilon = args.epsilon
@@ -32,6 +32,8 @@ if __name__ == "__main__":
     nruns = args.runs
     writefreq = args.writefreq
 
+    print(f"Will execute {nruns} run(s), will write output(s) in {output} every {writefreq} iteration(s)")
+
     rand_norms = True
     df_mini_scree_plots = pd.DataFrame(index=[], columns=[])
     for itrial in range(nruns):
@@ -55,10 +57,9 @@ if __name__ == "__main__":
         df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=ncmin, ncmax=ncmax)
         df_mini_scree_plots = nmf.add_miniscree_plots_from_scree_plot(df_mini_scree_plots, df_scree_plot, nb_clusters)
 
-        if itrial % writefreq == 0:
-            print(f"Saving iteration {itrial}")
+        if itrial % writefreq == 0 or itrial == nruns-1:
+            print(f"Saving iteration {itrial} in {output}")
             assert not df_mini_scree_plots.empty
-            output.to_csv(df_mini_scree_plots)
+            output.write(df_mini_scree_plots)
             assert output.isfile()
             assert not output.read().empty
-
